# Byzer-LLM

Byzerllm is a simple and easy to use python library for training, deploying and serving large language models.
It's also a bridge for [Byzer-SQL](https://github.com/byzer-org/byzer-lang) to manage the lifecycle of language models.

## Installation

```bash
pip install -r requirements.txt
pip install -U byzerllm
```

## Versions

- 0.1.5: Support python wrapper for [byzer-retrieval](https://github.com/allwefantasy/byzer-retrieval)


